# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

"""
This module contains a class for applying Critical CSS Advice
"""
import logging

from xray import gettext as _
from .wpos_base import WPOSModuleApply

logger = logging.getLogger('cpcss_advice')


class CPCSSAdvice(WPOSModuleApply):
    """Critical Path CSS advice"""

    short_description = _("Turn on Critical Path CSS")
    detailed_description = _("Critical Path CSS eliminates render-blocking CSS " 
                             "on your website and improves browser page render performance. " 
                             "Your website will load much faster for your visitors.\n" 
                             "Note: Applying the current advice will also enable the AccelerateWP feature.")
    apply_advice_button_text = None
    upgrade_to_apply_button_text = None
    email_view_advice_text = None
    email_subject = None
    module_name = 'critical_css'
    is_premium_feature = True
    suite = 'accelerate_wp_premium'
